.. _example-stream-server:

Example 2: echo server, using a StreamServer
============================================

.. literalinclude:: ../examples/echoserver1.py
    :language: python
    :linenos:
